@@ -4,9 +4,10 @@ import os
 from datetime import datetime
 
 import pkg_resources
-from paperscraper.xrxiv.xrxiv_api import MedRxivApi
 from tqdm import tqdm
 
+from ..xrxiv.xrxiv_api import MedRxivApi
+
 today = datetime.today().strftime('%Y-%m-%d')
 save_folder = pkg_resources.resource_filename('paperscraper', 'server_dumps')
 save_path = os.path.join(save_folder, f'medrxiv_{today}.jsonl')
