@@ -5,9 +5,9 @@ import sys
 
 import pkg_resources
 
-from paperscraper.arxiv import get_and_dump_arxiv_papers
-from paperscraper.pubmed import get_and_dump_pubmed_papers
-from paperscraper.xrxiv.xrxiv_query import XRXivQuery
+from .arxiv import get_and_dump_arxiv_papers
+from .pubmed import get_and_dump_pubmed_papers
+from .xrxiv.xrxiv_query import XRXivQuery
 
 logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
 logger = logging.getLogger(__name__)
